@@ -126,8 +126,8 @@ sub main
 {
         my ($options) = @_;
 
-        my $goal   = $ENV{PERLFORMANCE_TESTMODE_FAST} ? 5000 : 200_000;
-        my $count  = $ENV{PERLFORMANCE_TESTMODE_FAST} ? 1    : 5;
+        my $goal   = $options->{fastmode} ? 5000 : 200_000;
+        my $count  = $options->{fastmode} ? 1    : 5;
 
         my $result;
         my $t = timeit $count, sub { $result = run($goal) };
