@@ -89,8 +89,8 @@ sub main
 {
         my ($options) = @_;
 
-        my $goal   = $ENV{PERLFORMANCE_TESTMODE_FAST} ? "fasta-10000.txt" : "fasta-1000000.txt";
-        my $count  = $ENV{PERLFORMANCE_TESTMODE_FAST} ? 1 : 5;
+        my $goal   = $options->{fastmode} ? "fasta-10000.txt" : "fasta-1000000.txt";
+        my $count  = $options->{fastmode} ? 1 : 5;
 
         my $result;
         my $t = timeit $count, sub { $result = run($goal) };
